Installation — Scrapy-Redis 0.9.0 documentation

# Installation

## Stable release

To install Scrapy-Redis, run this command in your terminal:

    pip install scrapy-redis

If you don’t have pip installed, this Python installation guide can guide you through the process.

## From sources

The sources for Scrapy-Redis can be downloaded from the Github repo.

You can either clone the public repository:

    git clone git://github.com/rolando/scrapy-redis

Or download the tarball:

    curl  -OL https://github.com/rolando/scrapy-redis/tarball/master

Once you have a copy of the source, you can install it with:

    pip install -e .